Skip to contents

Calculates surrogate indices of beta-cell insulin secretion from fasting and oral glucose tolerance test (OGTT) glucose/insulin measurements.

Usage

insulin_release(data, category = c("fasting", "ogtt"))

Arguments

data

A data frame containing the columns required for the requested category (see Details).

category

Character vector selecting which indices to calculate. One or both of "fasting" and "ogtt". Defaults to both.

Value

The input data frame with the requested index columns appended.

Details

Required columns per category:

  • fasting: "G0", "I0"

  • ogtt: "G0", "I0", "G30", "I30", "G120", "I120", "sex", "bmi"

Expected units: glucose (G0, G30, G120) in mmol/L, insulin (I0, I30, I120) in pmol/L, bmi in kg/m^2, and sex as a male indicator (male = 1, female = 0). The BIGTT-AIR and BIGTT-SI terms enter sex as a linear multiplier, so any value other than 1 is treated as female; females coded as 2 are handled correctly. Internally, insulin is converted from pmol/L to microU/mL (value * 0.1667) and glucose from mmol/L to mg/dL (value * 18) where the source formula was derived in those units. If a required column is missing, the corresponding indices are skipped with a warning; missing values within a present column yield NA only for the indices that depend on them.

Indices calculated:

  • Homa_beta (fasting): HOMA-beta, an estimate of steady-state beta-cell function.

  • Cir (ogtt): Corrected Insulin Response.

  • Stumvoll (ogtt): Stumvoll first-phase insulin release index.

  • Xinsdg30 (ogtt): insulinogenic index using the 0-30 min glucose increment.

  • Xinsg30 (ogtt): insulinogenic index using the 30 min glucose value.

  • Di (ogtt): Disposition Index, transcribed exactly as reported in the Madsen (2024) index table: Xinsg30 * 1000 / (sqrt(G0_mgdl * I0_uU) * meanG_mgdl * meanI_uU).

  • Bigtt_air (ogtt): BIGTT Acute Insulin Response.

  • Dibig (ogtt): Disposition Index (Bigtt_air-based).

References

Madsen AL, et al. (2024). Genetic architecture of oral glucose-stimulated insulin release provides biological insights into type 2 diabetes aetiology. Nature Metabolism. doi:10.1038/s42255-024-01140-6

Examples

data(example_data)
insulin_release(example_data, category = "fasting")
#>      G0   G30 G120    I0   I30  I120 sex  bmi Glucagon0 Glucagon30 Glucagon120
#> 1  5.71  8.39 5.59  56.4 283.5 171.5   0 19.3      3.33       2.58        3.72
#> 2  5.06  8.45 6.31  39.7 153.9 115.1   0 29.4     13.71      10.10        6.92
#> 3  4.59  7.85 6.16  87.5 512.8 257.1   0 26.6      6.28       4.27        4.58
#> 4  5.29  7.72 7.01  71.7 390.1  67.7   1 21.4     11.36       8.71        8.77
#> 5  5.13  8.27 5.78  31.3 182.5  90.7   0 31.0     11.98       8.02        9.56
#> 6  5.20  9.56 5.12  52.9 374.3 155.3   1 27.7      9.40       7.17        9.05
#> 7  5.39  8.95 8.11  41.6 291.2 104.8   1 24.8      8.06       5.92        8.85
#> 8  5.01  8.24 5.79  42.4 221.1 172.1   1 29.6     10.50       6.71        9.53
#> 9  5.52  8.38 5.68  78.8 546.2 129.9   0 29.5     11.32       8.90       12.30
#> 10 5.09  6.65 6.01  72.5 296.1 171.5   0 29.3     12.65       9.67       12.55
#> 11 5.37  9.48 6.33  51.8 264.2 135.8   1 28.8      3.84       2.48        2.26
#> 12 5.75  7.78 8.28  38.2 218.7 125.8   1 28.2      5.09       3.91        3.05
#> 13 5.42  9.21 6.72  77.9 553.7 165.6   1 25.8     14.29      10.40        8.92
#> 14 5.04  9.77 7.14  67.1 384.5  77.4   0 24.8     13.14       9.65       10.27
#> 15 5.77  7.81 6.37  30.5 182.8  93.6   1 24.5     11.31       9.61        6.30
#> 16 5.70  9.46 7.16  50.9 239.6  90.9   0 23.2     12.15       9.91        7.84
#> 17 5.47  8.46 6.28  25.9 179.0  54.8   1 25.2     12.75       9.40       11.12
#> 18 5.32  7.26 6.63  27.7 141.1  41.6   0 20.9      2.02       1.53        1.54
#> 19 4.89  6.88 5.02  23.1  74.8  42.5   0 34.7     13.33       8.97       11.56
#> 20 5.88  7.80 5.51  46.5 294.4 134.0   0 30.8      8.55       5.32        8.89
#> 21 4.90  7.68 8.50  27.0 179.6  72.7   0 21.5     10.69       7.67        9.81
#> 22 6.29  8.32 8.21  57.1 293.8  98.1   1 24.4      9.11       5.50        6.87
#> 23 5.97  9.72 5.67  98.9 619.9 295.7   0 24.1     12.62      10.86       12.13
#> 24 5.08  9.96 5.55  52.9 189.4 185.1   0 29.1      8.95       8.04        5.11
#> 25 4.69  6.86 4.47  49.0 226.9 113.8   0 25.7     11.56       9.39        7.84
#> 26 4.84  8.67 8.68  52.4 334.8 102.3   0 27.0      8.83       7.49        7.82
#> 27 5.33  9.15 8.10  78.0 362.8 133.6   1 25.9      6.72       5.83        4.06
#> 28 5.08  8.55 5.96  47.2 246.4  24.7   1 25.8     13.63      10.38       14.38
#> 29 5.03  7.42 6.88  56.1 272.9 144.8   0 31.5     12.22       9.37       12.84
#> 30 4.72  7.82 5.42  89.7 607.9 231.0   1 25.1     15.17      10.36       12.30
#> 31 5.18  8.16 5.81 121.9 542.2 314.1   0 32.1     10.20       8.14       10.23
#> 32 4.81  8.46 5.06  97.3 628.3 307.7   1 19.8     13.38       9.01        9.26
#> 33 4.37  7.27 4.86  51.9 224.1 117.2   0 28.3     15.93      10.94        8.64
#> 34 5.01  8.99 8.19  71.0 365.7 141.2   1 26.5      9.16       7.46        7.20
#> 35 5.66  8.56 6.80  79.6 457.3 203.7   1 26.9      6.03       4.93        4.83
#> 36 4.91  8.95 6.25  41.8 159.8 107.9   0 27.5      9.28       6.05        6.70
#> 37 5.50  7.86 6.99  79.9 321.3 197.4   0 24.0      9.36       6.48        5.81
#> 38 4.39  6.58 7.07  72.2 524.2 168.9   0 24.7     10.46       7.44        8.68
#> 39 5.17 10.96 5.75  27.1 116.0 119.5   0 21.9     15.14       9.44        7.76
#> 40 5.46  8.33 5.47  48.4 298.6  86.8   1 21.7      9.02       7.34        9.05
#> 41 5.35  8.79 8.56  59.2 397.5 138.7   0 27.2     11.12       8.51        9.61
#> 42 5.25  8.96 5.92  56.8 338.0 103.3   1 27.8      9.32       5.97        8.55
#> 43 4.88  7.69 5.21  65.5 461.1 183.9   1 26.2     10.06       8.98        8.09
#> 44 4.78  8.39 4.50  55.6 238.0 163.6   0 29.7     10.94       8.41        7.46
#> 45 4.69  8.19 4.35  22.8 152.3  82.0   0 34.2     13.98      11.69       11.18
#> 46 5.26  8.29 5.77  37.1 195.4  95.9   0 24.0     10.36       8.85       10.52
#> 47 4.73  7.98 6.67  48.9 360.8 139.8   0 16.8     12.14      10.48       10.69
#> 48 4.95  8.12 7.48  86.8 441.2 248.8   1 30.0     12.34      10.37        9.34
#> 49 5.07  9.97 7.12  90.2 385.2 172.7   0 23.2     12.74      10.09       13.09
#> 50 6.12  8.73 6.88  50.6 263.2 123.0   0 23.2      8.28       6.53        5.85
#>    Homa_beta
#> 1   85.08489
#> 2   84.84603
#> 3  267.63761
#> 4  133.54626
#> 5   64.02098
#> 6  103.74624
#> 7   73.38328
#> 8   93.61695
#> 9  130.05901
#> 10 152.02201
#> 11  92.35358
#> 12  56.60391
#> 13 135.27010
#> 14 145.26714
#> 15  44.79604
#> 16  77.13664
#> 17  43.83279
#> 18  50.74275
#> 19  55.40676
#> 20  65.13908
#> 21  64.29857
#> 22  68.23348
#> 23 133.49498
#> 24 111.62570
#> 25 137.28235
#> 26 130.37433
#> 27 142.10492
#> 28  99.59797
#> 29 122.24667
#> 30 245.13098
#> 31 241.91345
#> 32 247.63221
#> 33 198.89034
#> 34 156.76424
#> 35 122.86407
#> 36  98.83773
#> 37 133.19330
#> 38 270.46607
#> 39  54.10263
#> 40  82.32939
#> 41 106.68800
#> 42 108.21211
#> 43 158.24420
#> 44 144.82062
#> 45  63.87832
#> 46  70.27920
#> 47 132.54683
#> 48 199.58014
#> 49 191.54573
#> 50  64.38947
insulin_release(example_data, category = c("fasting", "ogtt"))
#>      G0   G30 G120    I0   I30  I120 sex  bmi Glucagon0 Glucagon30 Glucagon120
#> 1  5.71  8.39 5.59  56.4 283.5 171.5   0 19.3      3.33       2.58        3.72
#> 2  5.06  8.45 6.31  39.7 153.9 115.1   0 29.4     13.71      10.10        6.92
#> 3  4.59  7.85 6.16  87.5 512.8 257.1   0 26.6      6.28       4.27        4.58
#> 4  5.29  7.72 7.01  71.7 390.1  67.7   1 21.4     11.36       8.71        8.77
#> 5  5.13  8.27 5.78  31.3 182.5  90.7   0 31.0     11.98       8.02        9.56
#> 6  5.20  9.56 5.12  52.9 374.3 155.3   1 27.7      9.40       7.17        9.05
#> 7  5.39  8.95 8.11  41.6 291.2 104.8   1 24.8      8.06       5.92        8.85
#> 8  5.01  8.24 5.79  42.4 221.1 172.1   1 29.6     10.50       6.71        9.53
#> 9  5.52  8.38 5.68  78.8 546.2 129.9   0 29.5     11.32       8.90       12.30
#> 10 5.09  6.65 6.01  72.5 296.1 171.5   0 29.3     12.65       9.67       12.55
#> 11 5.37  9.48 6.33  51.8 264.2 135.8   1 28.8      3.84       2.48        2.26
#> 12 5.75  7.78 8.28  38.2 218.7 125.8   1 28.2      5.09       3.91        3.05
#> 13 5.42  9.21 6.72  77.9 553.7 165.6   1 25.8     14.29      10.40        8.92
#> 14 5.04  9.77 7.14  67.1 384.5  77.4   0 24.8     13.14       9.65       10.27
#> 15 5.77  7.81 6.37  30.5 182.8  93.6   1 24.5     11.31       9.61        6.30
#> 16 5.70  9.46 7.16  50.9 239.6  90.9   0 23.2     12.15       9.91        7.84
#> 17 5.47  8.46 6.28  25.9 179.0  54.8   1 25.2     12.75       9.40       11.12
#> 18 5.32  7.26 6.63  27.7 141.1  41.6   0 20.9      2.02       1.53        1.54
#> 19 4.89  6.88 5.02  23.1  74.8  42.5   0 34.7     13.33       8.97       11.56
#> 20 5.88  7.80 5.51  46.5 294.4 134.0   0 30.8      8.55       5.32        8.89
#> 21 4.90  7.68 8.50  27.0 179.6  72.7   0 21.5     10.69       7.67        9.81
#> 22 6.29  8.32 8.21  57.1 293.8  98.1   1 24.4      9.11       5.50        6.87
#> 23 5.97  9.72 5.67  98.9 619.9 295.7   0 24.1     12.62      10.86       12.13
#> 24 5.08  9.96 5.55  52.9 189.4 185.1   0 29.1      8.95       8.04        5.11
#> 25 4.69  6.86 4.47  49.0 226.9 113.8   0 25.7     11.56       9.39        7.84
#> 26 4.84  8.67 8.68  52.4 334.8 102.3   0 27.0      8.83       7.49        7.82
#> 27 5.33  9.15 8.10  78.0 362.8 133.6   1 25.9      6.72       5.83        4.06
#> 28 5.08  8.55 5.96  47.2 246.4  24.7   1 25.8     13.63      10.38       14.38
#> 29 5.03  7.42 6.88  56.1 272.9 144.8   0 31.5     12.22       9.37       12.84
#> 30 4.72  7.82 5.42  89.7 607.9 231.0   1 25.1     15.17      10.36       12.30
#> 31 5.18  8.16 5.81 121.9 542.2 314.1   0 32.1     10.20       8.14       10.23
#> 32 4.81  8.46 5.06  97.3 628.3 307.7   1 19.8     13.38       9.01        9.26
#> 33 4.37  7.27 4.86  51.9 224.1 117.2   0 28.3     15.93      10.94        8.64
#> 34 5.01  8.99 8.19  71.0 365.7 141.2   1 26.5      9.16       7.46        7.20
#> 35 5.66  8.56 6.80  79.6 457.3 203.7   1 26.9      6.03       4.93        4.83
#> 36 4.91  8.95 6.25  41.8 159.8 107.9   0 27.5      9.28       6.05        6.70
#> 37 5.50  7.86 6.99  79.9 321.3 197.4   0 24.0      9.36       6.48        5.81
#> 38 4.39  6.58 7.07  72.2 524.2 168.9   0 24.7     10.46       7.44        8.68
#> 39 5.17 10.96 5.75  27.1 116.0 119.5   0 21.9     15.14       9.44        7.76
#> 40 5.46  8.33 5.47  48.4 298.6  86.8   1 21.7      9.02       7.34        9.05
#> 41 5.35  8.79 8.56  59.2 397.5 138.7   0 27.2     11.12       8.51        9.61
#> 42 5.25  8.96 5.92  56.8 338.0 103.3   1 27.8      9.32       5.97        8.55
#> 43 4.88  7.69 5.21  65.5 461.1 183.9   1 26.2     10.06       8.98        8.09
#> 44 4.78  8.39 4.50  55.6 238.0 163.6   0 29.7     10.94       8.41        7.46
#> 45 4.69  8.19 4.35  22.8 152.3  82.0   0 34.2     13.98      11.69       11.18
#> 46 5.26  8.29 5.77  37.1 195.4  95.9   0 24.0     10.36       8.85       10.52
#> 47 4.73  7.98 6.67  48.9 360.8 139.8   0 16.8     12.14      10.48       10.69
#> 48 4.95  8.12 7.48  86.8 441.2 248.8   1 30.0     12.34      10.37        9.34
#> 49 5.07  9.97 7.12  90.2 385.2 172.7   0 23.2     12.74      10.09       13.09
#> 50 6.12  8.73 6.88  50.6 263.2 123.0   0 23.2      8.28       6.53        5.85
#>    Homa_beta        Cir  Stumvoll  Xinsdg30   Xinsg30         Di Bigtt_air
#> 1   85.08489 0.38624419  850.5693 0.7847755  4.512225 0.04323715 1161.7892
#> 2   84.84603 0.20544797  542.2165 0.3119820  2.252916 0.04498467 1650.5366
#> 3  267.63761 0.84850015 1462.1662 1.2082057  9.031530 0.04893109 3477.8539
#> 4  133.54626 0.67861662 1196.1813 1.2134723  6.875295 0.05766393 2609.2182
#> 5   64.02098 0.25915744  587.8071 0.4459490  3.047768 0.07130919 1734.9674
#> 6  103.74624 0.35520933  841.1615 0.6826883  5.604328 0.05052567 2111.0444
#> 7   73.38328 0.33076005  731.1550 0.6493184  4.648974 0.05472084 2126.2318
#> 8   93.61695 0.31728676  704.4367 0.5123717  3.615205 0.05178532 2184.4180
#> 9  130.05901 0.74669710 1416.9274 1.5135117  9.297802 0.05222469 2832.8436
#> 10 152.02201 0.82970454 1175.6819 1.3274259  5.605131 0.05270061 2552.1323
#> 11  92.35358 0.25645841  646.7354 0.4786034  3.734924 0.04052172 1920.8472
#> 12  56.60391 0.37169451  748.0067 0.8234633  3.867526 0.05413571 2127.6611
#> 13 135.27010 0.58130379 1312.1291 1.1626482  8.611928 0.04263804 3072.0956
#> 14 145.26714 0.34429680  884.2527 0.6214538  5.415617 0.04391487 2078.6996
#> 15  44.79604 0.30711894  649.1402 0.6914055  3.250757 0.06930063 1516.2147
#> 16  77.13664 0.23390766  601.1212 0.4647797  3.325189 0.03970777 1260.1314
#> 17  43.83279 0.23815049  534.6838 0.4742061  3.016758 0.08361592 1576.5301
#> 18  50.74275 0.29662511  638.5943 0.5413454  2.603826 0.09189113 1333.0225
#> 19  55.40676 0.18701274  552.6864 0.2406027  1.252673 0.08657447 1934.4658
#> 20  65.13908 0.49651645  914.9956 1.1957445  5.298068 0.06087733 1712.0573
#> 21  64.29857 0.31737242  648.1164 0.5083617  3.312294 0.08469111 1804.5633
#> 22  68.23348 0.41002130  881.7574 1.0798547  4.742535 0.04228979 1768.1882
#> 23 133.49498 0.56272297 1441.6839 1.2866770  8.935257 0.02938318 1966.8487
#> 24 111.62570 0.16115473  447.4994 0.2590454  2.284593 0.02742134 1373.8272
#> 25 137.28235 0.57277239  931.3461 0.7592404  4.323022 0.07909343 1950.6806
#> 26 130.37433 0.41555461  890.4730 0.6828558  5.429767 0.05435171 2680.2708
#> 27 142.10492 0.38775669  971.6722 0.6904619  5.188651 0.03397313 2611.3307
#> 28  99.59797 0.31810883  725.8190 0.5316465  3.883818 0.06964906 2064.2328
#> 29 122.24667 0.53589393  964.5893 0.8400874  4.870695 0.05481873 2591.5193
#> 30 245.13098 1.01742091 1648.5635 1.5480993 11.046540 0.05573838 4291.9953
#> 31 241.91345 0.80042211 1602.6986 1.3061896  8.586276 0.03158436 3542.4672
#> 32 247.63221 0.83592152 1625.7743 1.3473014 10.463085 0.04421527 3252.5510
#> 33 198.89034 0.46907101  880.2967 0.5499184  3.948520 0.06997499 2308.9275
#> 34 156.76424 0.41029013  972.7643 0.6857411  5.464571 0.03912266 2984.7325
#> 35 122.86407 0.58843409 1232.3809 1.2061799  7.355443 0.03854411 2679.9004
#> 36  98.83773 0.18150912  491.5788 0.2704978  2.197832 0.04267989 1559.9005
#> 37 133.19330 0.52962287 1081.8585 0.9473018  5.119768 0.03471561 1875.4067
#> 38 270.46607 1.52310584 1601.4542 1.9114257 11.451125 0.08066950 4408.8550
#> 39  54.10263 0.07701057   77.2332 0.1421956  1.352156 0.03442589  836.4816
#> 40  82.32939 0.41528262  856.3332 0.8073624  5.007004 0.06383273 1692.1456
#> 41 106.68800 0.47472740 1014.1569 0.9107657  6.415769 0.04618561 2492.3465
#> 42 108.21211 0.38273322  872.6996 0.7019473  5.231701 0.05231896 2289.7367
#> 43 158.24420 0.81161265 1306.8149 1.3038062  8.575620 0.06574602 3214.9764
#> 44 144.82062 0.32425438  764.3322 0.4679298  3.624086 0.04764691 1849.3124
#> 45  63.87832 0.22244668  511.6053 0.3426611  2.635855 0.09963470 1870.2119
#> 46  70.27920 0.27554865  630.5048 0.4838396  3.183186 0.06218738 1367.8115
#> 47 132.54683 0.56860798 1020.5280 0.8887817  6.515505 0.06965815 1887.7286
#> 48 199.58014 0.66071723 1291.1204 1.0353747  7.275675 0.03807327 3964.9067
#> 49 191.54573 0.32688784  944.9262 0.5575567  4.932447 0.02780826 1922.3620
#> 50  64.38947 0.32041820  744.4050 0.7543725  4.059613 0.04208445 1201.8448
#>       Dibig
#> 1  13100.08
#> 2  16881.84
#> 3  24216.89
#> 4  24179.56
#> 5  17734.61
#> 6  16087.13
#> 7  18446.94
#> 8  17499.73
#> 9  18592.37
#> 10 20198.09
#> 11 14330.20
#> 12 15865.84
#> 13 18564.25
#> 14 20084.37
#> 15 15244.70
#> 16 13326.48
#> 17 17289.47
#> 18 20901.01
#> 19 21676.63
#> 20 13351.09
#> 21 25853.58
#> 22 12874.56
#> 23 10474.03
#> 24 12237.10
#> 25 24406.13
#> 26 24755.32
#> 27 17533.00
#> 28 21815.67
#> 29 20509.37
#> 30 26797.73
#> 31 14765.73
#> 32 21437.79
#> 33 26623.17
#> 34 20878.65
#> 35 14997.33
#> 36 17449.39
#> 37 15039.79
#> 38 39267.22
#> 39 11905.85
#> 40 17952.81
#> 41 19035.63
#> 42 18062.61
#> 43 24080.26
#> 44 17584.10
#> 45 20352.16
#> 46 17189.31
#> 47 26888.77
#> 48 19928.16
#> 49 15832.67
#> 50 11503.76